@@ -38,6 +38,8 @@ from ..types import (
     GetResponse,
     InvokeRequest,
     InvokeResponse,
+    InvokeScriptRequest,
+    InvokeScriptResponse,
     SetRequest,
     SetResponse,
     StaticGetRequest,
@@ -158,6 +160,10 @@ class _NodeProcess:
             LoadRequest,
             _with_api_key("load", self._serializer.unstructure_attrs_asdict),
         )
+        self._serializer.register_unstructure_hook(
+            InvokeScriptRequest,
+            _with_api_key("invokeBinScript", self._serializer.unstructure_attrs_asdict),
+        )
         self._serializer.register_unstructure_hook(
             CreateRequest,
             _with_api_key("create", self._serializer.unstructure_attrs_asdict),
@@ -292,10 +298,7 @@ class _NodeProcess:
         try:
             self._process.wait(timeout=5)
         except subprocess.TimeoutExpired:
-            try:
-                self._process.terminate(timeout=5)
-            except subprocess.TimeoutExpired:
-                self._process.kill()
+            self._process.terminate()
 
         self._ctx_stack.close()
 
@@ -343,6 +346,9 @@ class ProcessProvider(BaseProvider):
     def load(self, request: LoadRequest) -> LoadResponse:
         return self._process.send(request, LoadResponse)
 
+    def invokeBinScript(self, request: InvokeScriptRequest) -> InvokeScriptResponse:
+        return self._process.send(request, InvokeScriptResponse)
+
     def create(self, request: CreateRequest) -> CreateResponse:
         return self._process.send(request, CreateResponse)
 
